@@ -1,7 +1,7 @@
 package Perinci::To::POD;
 
-our $DATE = '2019-07-26'; # DATE
-our $VERSION = '0.867'; # VERSION
+our $DATE = '2020-01-28'; # DATE
+our $VERSION = '0.868'; # VERSION
 
 use 5.010001;
 use Log::ger;
@@ -15,6 +15,11 @@ sub BUILD {
     my ($self, $args) = @_;
 }
 
+sub _podquote {
+    require String::PodQuote;
+    String::PodQuote::pod_quote($_[0]);
+}
+
 sub _md2pod {
     require Markdown::To::POD;
 
@@ -42,7 +47,7 @@ sub gen_doc_section_summary {
     $self->add_doc_lines(
         "=head1 " . uc(__("Name")),
         "",
-        $name_summary,
+        $self->_podquote($name_summary),
         "",
     );
 }
@@ -174,8 +179,8 @@ sub gen_doc_section_links {
             $url =~ s!\A(pm|pod|prog):(//?)?!!;
             $self->add_doc_lines(
                 "L<$url>." .
-                    ($link->{summary} ? " $link->{summary}." : "") .
-                    ($link->{description} ? " " . $self->_md2pod($link->{description}) : ""),
+                    (defined $link->{summary} ? " ".$self->_podquote($link->{summary})."." : "") .
+                    (defined $link->{description} ? " " . $self->_md2pod($link->{description}) : ""),
                 "");
         }
     }
@@ -196,7 +201,7 @@ Perinci::To::POD - Generate POD documentation for a package from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.867 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2019-07-26.
+This document describes version 0.868 of Perinci::To::POD (from Perl distribution Perinci-To-Doc), released on 2020-01-28.
 
 =head1 SYNOPSIS
 
@@ -236,7 +241,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
