@@ -1,7 +1,7 @@
 package Perinci::To::PackageBase;
 
-our $DATE = '2019-07-26'; # DATE
-our $VERSION = '0.867'; # VERSION
+our $DATE = '2020-01-28'; # DATE
+our $VERSION = '0.868'; # VERSION
 
 use 5.010;
 use Data::Dump::OneLine qw(dump1);
@@ -105,7 +105,7 @@ sub gen_doc_section_functions {
     for my $furi (@func_uris) {
         my $fname = $furi; $fname =~ s!.+/!!;
         my $meta = $cmetas->{$furi};
-        next if $meta->{'x.no_index'};
+        next if $meta->{'x.no_index'} || grep { $_ eq 'hidden' } @{ $meta->{tags} // [] };
         push @{ $dres->{function_names_by_meta_addr}{"$meta"} }, $fname;
         $dres->{functions}{$furi} =
             $self->_gen_func_doc(
@@ -140,7 +140,7 @@ Perinci::To::PackageBase - Base class for Perinci::To::* package documentation g
 
 =head1 VERSION
 
-This document describes version 0.867 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2019-07-26.
+This document describes version 0.868 of Perinci::To::PackageBase (from Perl distribution Perinci-To-Doc), released on 2020-01-28.
 
 =for Pod::Coverage .+
 
@@ -166,7 +166,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2019, 2018, 2017, 2016, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
